==> swh.model-0.6.5.tar.gz: swh.model-0.6.5/setup.py <==
#!/usr/bin/env python3
# Copyright (C) 2015-2020  The Software Heritage developers
# See the AUTHORS file at the top-level directory of this distribution
# License: GNU General Public License version 3, or any later version
# See top-level LICENSE file for more information

from setuptools import setup, find_packages

from os import path
from io import open

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, "README.md"), encoding="utf-8") as f:
    long_description = f.read()


def parse_requirements(name=None):
    if name:
        reqf = "requirements-%s.txt" % name
    else:
        reqf = "requirements.txt"

    requirements = []
    if not path.exists(reqf):
        return requirements

    with open(reqf) as f:
        for line in f.readlines():
            line = line.strip()
            if not line or line.startswith("#"):
                continue
            requirements.append(line)
    return requirements


blake2_requirements = ['pyblake2;python_version<"3.6"']

setup(
    name="swh.model",
    description="Software Heritage data model",
    long_description=long_description,
    long_description_content_type="text/markdown",
    python_requires=">=3.7",
    author="Software Heritage developers",
    author_email="swh-devel@inria.fr",
    url="https://forge.softwareheritage.org/diffusion/DMOD/",
    packages=find_packages(),
    setup_requires=["setuptools-scm"],
    use_scm_version=True,
    install_requires=(
        parse_requirements() + parse_requirements("swh") + blake2_requirements
    ),
    extras_require={
        "cli": parse_requirements("cli"),
        "testing": parse_requirements("test"),
    },
    include_package_data=True,
    entry_points="""
        [console_scripts]
        swh-identify=swh.model.cli:identify
        [swh.cli.subcommands]
        identify=swh.model.cli:identify
    """,
    classifiers=[
        "Programming Language :: Python :: 3",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
        "Development Status :: 5 - Production/Stable",
    ],
    project_urls={
        "Bug Reports": "https://forge.softwareheritage.org/maniphest",
        "Funding": "https://www.softwareheritage.org/donate",
        "Source": "https://forge.softwareheritage.org/source/swh-model",
        "Documentation": "https://docs.softwareheritage.org/devel/swh-model/",
    },
)

==> swh.model-2.2.0.tar.gz: swh.model-2.2.0/setup.py <==
#!/usr/bin/env python3
# Copyright (C) 2015-2020  The Software Heritage developers
# See the AUTHORS file at the top-level directory of this distribution
# License: GNU General Public License version 3, or any later version
# See top-level LICENSE file for more information

from io import open
from os import path

from setuptools import find_packages, setup

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, "README.md"), encoding="utf-8") as f:
    long_description = f.read()


def parse_requirements(name=None):
    if name:
        reqf = "requirements-%s.txt" % name
    else:
        reqf = "requirements.txt"

    requirements = []
    if not path.exists(reqf):
        return requirements

    with open(reqf) as f:
        for line in f.readlines():
            line = line.strip()
            if not line or line.startswith("#"):
                continue
            requirements.append(line)
    return requirements


blake2_requirements = ['pyblake2;python_version<"3.6"']

setup(
    name="swh.model",
    description="Software Heritage data model",
    long_description=long_description,
    long_description_content_type="text/markdown",
    python_requires=">=3.7",
    author="Software Heritage developers",
    author_email="swh-devel@inria.fr",
    url="https://forge.softwareheritage.org/diffusion/DMOD/",
    packages=find_packages(),
    setup_requires=["setuptools-scm"],
    use_scm_version=True,
    install_requires=(
        parse_requirements() + parse_requirements("swh") + blake2_requirements
    ),
    extras_require={
        "cli": parse_requirements("cli"),
        "testing": parse_requirements("test") + parse_requirements("cli"),
    },
    include_package_data=True,
    entry_points="""
        [console_scripts]
        swh-identify=swh.model.cli:identify
        [swh.cli.subcommands]
        identify=swh.model.cli
    """,
    classifiers=[
        "Programming Language :: Python :: 3",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
        "Development Status :: 5 - Production/Stable",
    ],
    project_urls={
        "Bug Reports": "https://forge.softwareheritage.org/maniphest",
        "Funding": "https://www.softwareheritage.org/donate",
        "Source": "https://forge.softwareheritage.org/source/swh-model",
        "Documentation": "https://docs.softwareheritage.org/devel/swh-model/",
    },
)
